pub struct ResultValue { /* private fields */ }
Denotes a successful or unsuccessful operation, associated optionally with types.

Implementations

source

impl ResultValue

source

pub fn new( ty: ResultType, value: Result<Option<Value>, Option<Value>> ) -> Result<Self>

Creates a new result from the provided type and value. The value must match that which is described in the type.

source

pub fn ty(&self) -> ResultType

The type of this result.