Struct wasm_component_layer::ResultValue
source · pub struct ResultValue { /* private fields */ }Expand description
Denotes a successful or unsuccessful operation, associated optionally with types.
Implementations
sourceimpl ResultValue
impl ResultValue
sourcepub fn new(
ty: ResultType,
value: Result<Option<Value>, Option<Value>>
) -> Result<Self>
pub fn new( ty: ResultType, value: Result<Option<Value>, Option<Value>> ) -> Result<Self>
Creates a new result from the provided type and value. The value must match that which is described in the type.
sourcepub fn ty(&self) -> ResultType
pub fn ty(&self) -> ResultType
The type of this result.